@@ -2,15 +2,15 @@
 
 #
 # DaVinci Resolve Multi Debian package creator
-# Release 2020-10-12
+# Release 2020-10-21
 # By Daniel Tufvesson
 #
-MAKERESOLVEDEB_VERSION=1.3
+MAKERESOLVEDEB_VERSION=1.3.1
 
 check_command() {
     echo -n "Checking for ${1}..."
     if [[ ! -x "$(command -v $1)" ]]; then
-	echo "Missing! Sorry, seed '$1' to continue."
+	echo "Missing! Sorry, need '$1' to continue."
 	exit 1
     fi
     echo "found!"
